@@ -246,15 +246,15 @@ class State:
             device = getattr(
                 # This device's channel.
                 getattr(self.channels, config.system.channel),
-                config.system.device)
+                config.device)
         except AttributeError:
             log.info('no matching channel/device: %s/%s',
-                     config.system.channel, config.system.device)
+                     config.system.channel, config.device)
             # Either our channel or device isn't described in the
             # channels.json file, so there's nothing more to do.
             return
         log.info('found channel/device entry: %s/%s',
-                 config.system.channel, config.system.device)
+                 config.system.channel, config.device)
         keyring = getattr(device, 'keyring', None)
         if keyring:
             self._next.append(partial(self._get_device_keyring, keyring))
@@ -307,6 +307,8 @@ class State:
         # doing the reboot.
         if len(self.winner) > 0:
             self._next.append(self._download_files)
+        else:
+            log.info('No update available.')
 
     def _download_files(self):
         """Download and verify all the winning upgrade path's files."""
@@ -459,6 +461,7 @@ class State:
         #   ((image_number, order), file_2, file_2.asc),
         #   ...
         # ]
+        log.info('preparing to reboot')
         collated = []
         zipper = zip(
             # items # 0, 2, 4, ...
@@ -501,5 +504,6 @@ class State:
         self._next.append(self._reboot)
 
     def _reboot(self):
+        log.info('rebooting')
         config.hooks.reboot().reboot()
         # Nothing more to do.
